@@ -69,7 +69,7 @@ CREATE TABLE device (
    *     permission.  This permission is only granted to apps signed with
    *     the platform key and privileged system apps.
    *
-   * @note: Serial number is case sensitive.
+   * @note: The serial number is case sensitive.
    */
   serial_number text NULL,
 
@@ -164,7 +164,100 @@ CREATE TABLE device (
   battery_plug_mode text NULL,
 
   /**
-   * Current status of this mobile device:
+   * The geographical coordinates of the last known position of the mobile
+   * device.
+   *
+   *
+   * @todo: This information should be updated into a cache database (e.g.,
+   *     Redis).
+   */
+  location geometry NULL,
+
+  /**
+   * The accuracy in meters of the last known position of the mobile device.
+   *
+   *
+   * @todo: This information should be updated into a cache database (e.g.,
+   *     Redis).
+   */
+  accuracy float NULL,
+
+  /**
+   * The horizontal direction of travel, expressed in degrees, of the
+   * mobile device when this location has been determined.  It is
+   * guaranteed to be in the range `[0.0, 360.0]`.
+   *
+   *
+   * @todo: This information should be updated into a cache database (e.g.,
+   *     Redis).
+   */
+  bearing float NULL,
+
+  /**
+   * The speed in meters/second over the ground of the mobile device when
+   * this location has been determined.
+   *
+   *
+   * @todo: This information should be updated into a cache database (e.g.,
+   *     Redis).
+   */
+  speed float NULL,
+
+  /**
+   * The time when the mobile device determined the information of this fix.
+   *
+   *
+   * @todo: This information should be updated into a cache database (e.g.,
+   *     Redis).
+   */
+  fix_time timestamptz(3) NULL,
+
+  /**
+   * The type of the location provider that reported the geographical
+   * location such as:
+   *
+   * - `fused`: The location API in Google Play services that combines
+   *   different signals to provide the location information.
+   *
+   * - `gps`: This provider determines location using satellites.
+   *
+   * - `network`: This provider determines location based on availability of
+   *   cell towers and Wi-Fi access points.  Results are retrieved by means
+   *   of a network lookup.
+   *
+   * - `passive`: A special location provider for receiving locations without
+   *   actually initiating a location fix.  This provider can be used to
+   *   passively receive location updates when other applications or services
+   *   request them without actually requesting the locations yourself.  This
+   *   provider will return locations generated by other providers.
+   *
+   *
+   * @todo: This information should be updated into a cache database (e.g.,
+   *     Redis).
+   */
+  provider text NULL,
+
+  /**
+   * The time of the last keep-alive (KA) messages sent the mobile device.
+   *
+   *
+   * @todo: This information should be updated into a cache database (e.g.,
+   *     Redis).
+   */
+  keepalive_time timestamptz(3) NULL,
+
+  /**
+   * The level in percentage of the mobile device's battery (expressed
+   * between `0.0` and `1.1`) when this event occurred.
+   *
+   *
+   * @todo: This information should be updated into a cache database (e.g.,
+   *     Redis).
+   */
+  battery_level float NULL,
+
+  /**
+   * The current status of the mobile device:
    *
    * - `deleted`: The device has been banned by an administrator of the
    *   server platform.
@@ -200,6 +293,7 @@ CREATE TABLE device (
  * The list of applications that have been once installed on a device,
  * and their respective version.
  *
+ *
  * @warning: When the individual user or the organization owning the
  *     mobile device transfer the ownership to another individual user
  *     or organization, the server platform must automatically
@@ -227,9 +321,11 @@ CREATE TABLE device_app (
    * The security key generated by the server platform and shared with the
    * application installed on the device to secure the communication.
    *
+   *
    * @note: The security key is generated when the application is activated
    *     on this device.
    *
+   *
    * @note: A new security key MUST be generated when the ownership of the
    *     device is transferred to another organization.
    */
@@ -408,12 +504,12 @@ CREATE TABLE device_battery_event (
   /**
    * The geographical coordinates of the position of the mobile device when
    * this event occurred.
-  */
+   */
   location geometry NULL,
 
   /**
    * The accuracy in meters of the location.
-  */
+   */
   accuracy float NULL,
 
   /**
