@@ -90,6 +90,7 @@ class DeviceServiceHttpRequestHandler(HttpRequestHandler):
 
         token = request.get_argument(
             'token',
+            argument_passing=HttpRequest.ArgumentPassing.query_string,
             data_type=HttpRequest.ArgumentDataType.string,
             is_required=True
         )
@@ -134,6 +135,7 @@ class DeviceServiceHttpRequestHandler(HttpRequestHandler):
 
         token = request.get_argument(
             'token',
+            argument_passing=HttpRequest.ArgumentPassing.query_string,
             data_type=HttpRequest.ArgumentDataType.string,
             is_required=True
         )
@@ -156,21 +158,25 @@ class DeviceServiceHttpRequestHandler(HttpRequestHandler):
         events = request.get_argument(
             'events',
             data_type=HttpRequest.ArgumentDataType.list,
-            item_data_type = HttpRequest.ArgumentDataType.object,
+            item_data_type=HttpRequest.ArgumentDataType.object,
             object_class=LocationUpdate,
-            is_required=True)
+            is_required=True
+        )
 
         token = request.get_argument(
             'token',
+            argument_passing=HttpRequest.ArgumentPassing.query_string,
             data_type=HttpRequest.ArgumentDataType.string,
-            is_required=True)
+            is_required=True
+        )
 
         return DeviceService().report_location_events(
             request.app_id,
             device_id,
             events,
             token,
-            account_id=request.session and request.session.account_id)
+            account_id=request.session and request.session.account_id
+        )
 
     @http_request(r'^/device/(device_id:string)/handshake$',
                   http_method=HttpMethod.POST,
